MethodChannelMobigoiotApi class

Inheritance

Constructors

MethodChannelMobigoiotApi()

Properties

hashCode → int
The hash code for this object.
no setterinherited
printingMethodChannel → MethodChannel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scannerEventChannel → EventChannel
final
scanningMethodChannel → MethodChannel
final

Methods

getScanResult() → Stream<ScannerResult?>?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printBitmap(Uint8List data) → Future<bool?>
override
printEndLine() → Future<bool?>
override
printText(String text) → Future<bool?>
override
printTextFull({required String text, PrinterTextStyle? style}) → Future<bool?>
override
startScanner({bool turnOnFlash = false, bool turnOnBeep = false, bool turnOnVibration = false, ScannerMode scannerMode = ScannerMode.single, int delay = 500}) → Future<bool?>
override
stopScanner() → Future<bool?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited