PrinterTextStyle class

Constructors

PrinterTextStyle({PTextSize? textSize, PTextDirection? textDirection, PTextFont? textFont, PTextAlignment? alignment, bool isBold = false, bool isUnderlined = false})

Properties

alignment → PTextAlignment?
final
hashCode → int
The hash code for this object.
no setterinherited
isBold → bool
final
isUnderlined → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textDirection → PTextDirection?
final
textFont → PTextFont?
final
textSize → PTextSize?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited