ScannerResult class

Constructors

ScannerResult({String? value, int? symbology, int? subtype, String? aimID, int? decoderType})
ScannerResult.fromMap(Map? map)

Properties

aimID → String?
final
decoderType → int?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtype → int?
final
symbology → int?
final
value → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited