MethodChannelMobigoiotApi class

Inheritance

Constructors

MethodChannelMobigoiotApi()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printBitmap(Uint8List data) → Future<bool?>
override
printEndLine() → Future<bool?>
override
printText(String text) → Future<bool?>
override
printTextFull({required String text, PrinterTextStyle? style}) → Future<bool?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited